==> selenium-server-2.7.0-sources.jar: org/openqa/selenium/remote/server/handler/ImplicitlyWait.java <==
/*
Copyright 2007-2010 WebDriver committers
Copyright 2007-2010 Google Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 */

package org.openqa.selenium.remote.server.handler;

import org.openqa.selenium.remote.server.JsonParametersAware;
import org.openqa.selenium.remote.server.Session;
import org.openqa.selenium.remote.server.rest.ResultType;

import java.util.Map;
import java.util.concurrent.TimeUnit;

public class ImplicitlyWait extends WebDriverHandler implements JsonParametersAware {

  private volatile long millis;

  public ImplicitlyWait(Session session) {
    super(session);
  }

  public void setJsonParameters(Map<String, Object> allParameters) throws Exception {
    millis = ((Number) allParameters.get("ms")).longValue();
  }

  public ResultType call() throws Exception {
    getDriver().manage().timeouts().implicitlyWait(millis, TimeUnit.MILLISECONDS);

    return ResultType.SUCCESS;
  }

  @Override
  public String toString() {
    return String.format("[implicitly wait: %s]", millis);
  }
}

==> selenium-server-2.33.0-sources.jar: org/openqa/selenium/remote/server/handler/ImplicitlyWait.java <==
/*
Copyright 2007-2010 Selenium committers

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 */

package org.openqa.selenium.remote.server.handler;

import org.openqa.selenium.WebDriverException;
import org.openqa.selenium.remote.server.JsonParametersAware;
import org.openqa.selenium.remote.server.Session;
import org.openqa.selenium.remote.server.rest.ResultType;

import java.util.Map;
import java.util.concurrent.TimeUnit;

public class ImplicitlyWait extends WebDriverHandler implements JsonParametersAware {

  private volatile long millis;

  public ImplicitlyWait(Session session) {
    super(session);
  }

  public void setJsonParameters(Map<String, Object> allParameters) throws Exception {
    try {
      millis = ((Number) allParameters.get("ms")).longValue();
    } catch (ClassCastException ex) {
      throw new WebDriverException("Illegal (non-numeric) timeout value passed: " + allParameters.get("ms"), ex);
    }
  }

  public ResultType call() throws Exception {
    getDriver().manage().timeouts().implicitlyWait(millis, TimeUnit.MILLISECONDS);

    return ResultType.SUCCESS;
  }

  @Override
  public String toString() {
    return String.format("[implicitly wait: %s]", millis);
  }
}
